@@ -2,6 +2,7 @@
 #define QT_FEATURE_datetimeparser 1
 #define QT_FEATURE_dlopen 1
 #define QT_FEATURE_doubleconversion 1
+#define QT_FEATURE_etw -1
 #define QT_FEATURE_futimens 1
 #define QT_FEATURE_futimes -1
 #define QT_FEATURE_getauxval 1
@@ -14,6 +15,7 @@
 #define QT_FEATURE_inotify 1
 #define QT_FEATURE_journald 1
 #define QT_FEATURE_linkat 1
+#define QT_FEATURE_lttng -1
 #define QT_FEATURE_poll_ppoll 1
 #define QT_FEATURE_poll_poll -1
 #define QT_FEATURE_poll_pollts -1
