@@ -15,6 +15,8 @@
 #define QT_FEATURE_eglfs_rcar -1
 #define QT_FEATURE_eglfs_viv -1
 #define QT_FEATURE_eglfs_viv_wl -1
+#define QT_FEATURE_vsp2 -1
+#define QT_FEATURE_eglfs_vsp2 -1
 #define QT_FEATURE_evdev 1
 #define QT_FEATURE_freetype 1
 #define QT_FEATURE_system_freetype 1
@@ -37,6 +39,7 @@
 #define QT_FEATURE_system_png 1
 #define QT_FEATURE_system_xcb 1
 #define QT_FEATURE_tslib 1
+#define QT_FEATURE_tuiotouch 1
 #define QT_FEATURE_vnc 1
 #define QT_FEATURE_xcb_glx 1
 #define QT_FEATURE_xlib 1
@@ -46,6 +49,6 @@
 #define QT_FEATURE_xcb_sm 1
 #define QT_FEATURE_xinput2 1
 #define QT_FEATURE_xkb 1
-#define QT_FEATURE_xkbcommon_system 1
 #define QT_FEATURE_xkbcommon_evdev 1
+#define QT_FEATURE_xkbcommon_system 1
 #define QT_FEATURE_xrender 1
